==> tdm_3.0.0.tar.gz: tdm/R/all.Theirss.R <==
all.Theirss<-function(){
     cat("\n")                                                                      
     cat("----------------------------------------------------\n")
     cat("    --Theophylline IR input data information--      \n")
     note_for_Theirss_input()
     cat("----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     TheirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),
                            value=c(1,65,167,0,1,300,8,8,5.67))                    
     TheirSSpar<-edit(TheirSSpar)                                                                                                                     
##     TheirSSpar<-ycheck(TheirSSpar)   
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(TheirSSpar);cat("\n\n")                                                                                                                 
     Their.ss(TheirSSpar[9,2],TheirSSpar[7,2],TheirSSpar[8,2],TheirSSpar[6,2],TheirSSpar[3,2],TheirSSpar[2,2],TheirSSpar[5,2],TheirSSpar[1,2],TheirSSpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     X <- read.table("params.csv",header=FALSE)
     cl_F <- X[1,2]
     v_F  <- X[2,2]
     cat("---------------------------------------\n")
     cat("       -- Output Annotations--         \n")
     note_for_Theirss_output()
     cat("---------------------------------------\n")
     ### show(samplesStats("*"))
     cat("\n") 
     C1<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],TheirSSpar[8,2])
     Tmax=log(1.85-(cl_F/v_F))/(1.85-(cl_F/v_F))
     C2<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],Tmax)
     C3<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],TheirSSpar[7,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(conc=c("Cmss_obs","** Cmss_pr","** Cpss_pr","** Ctss_pr"),value=c(TheirSSpar[9,2],C1,C2,C3))
     show(coutput)     
     cat("\n")  
     Their.more()                      
}

==> tdm_3.0.2.tar.gz: tdm/R/all.Theirss.R <==
all.Theirss<-function(){
     cat("\n")                                                                      
     cat("----------------------------------------------------\n")
     cat("    --Theophylline IR input data information--      \n")
     note_for_Theirss_input()
     cat("----------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     TheirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),
                            value=c(1,65,167,0,1,300,8,8,5.67))                    
     TheirSSpar<-edit(TheirSSpar)                                                                                                                     
##     TheirSSpar<-ycheck(TheirSSpar)   
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(TheirSSpar);cat("\n\n")                                                                                                                 
     Their.ss(TheirSSpar[9,2],TheirSSpar[7,2],TheirSSpar[8,2],TheirSSpar[6,2],TheirSSpar[3,2],TheirSSpar[2,2],TheirSSpar[5,2],TheirSSpar[1,2],TheirSSpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     X <- read.table("params.csv",header=FALSE)
     cl_F <- X[1,2]
     v_F  <- X[2,2]
     cat("---------------------------------------\n")
     cat("       -- Output Annotations--         \n")
     note_for_Theirss_output()
     cat("---------------------------------------\n")
     ### show(samplesStats("*"))
     cat("\n") 
     C1<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],TheirSSpar[8,2])
     Tmax=log(1.85/(cl_F/v_F))/(1.85-(cl_F/v_F))
     C2<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],Tmax)
     C3<-TheIRsscpr(1,TheirSSpar[6,2],TheirSSpar[7,2],TheirSSpar[7,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(conc=c("Cmss_obs","** Cmss_pr","** Cpss_pr","** Ctss_pr"),value=c(TheirSSpar[9,2],C1,C2,C3))
     show(coutput)     
     cat("\n")  
     Their.more()                      
}
